Summarizes inbreeding accumulation in the population simulated by
aRetain. Must be run after aRetain is run with
trackall = TRUE.
Requires package pedigree.
pedigree.summary(adata)list of output from aRetain
A matrix in which the rows correspond to simulation years (0,...,nyears) and the columns are summary variables:
year of simulation
mean F, averaged across individuals and then across replicates
inter-replicate variance in F
inter-individual variance of F, averaged across replicates
Weiser, E.L., Grueber, C. E., and I. G. Jamieson. 2012. AlleleRetain: A program to assess management options for conserving allelic diversity in small, isolated populations. Molecular Ecology Resources 12:1161-1167.