Summarizes inbreeding accumulation in the population simulated by
aRetain. Must be run after aRetain is run with trackall = TRUE.
Requires package pedigree.
Usage
pedigree.summary(adata)
Arguments
adata
list of output from aRetain
Value
A matrix in which the rows correspond to simulation years (0,...,nyears) and
the columns are summary variables:
yearyear of simulation
meanFmean F, averaged across individuals and then across replicates
varFinter-replicate variance in F
indivVarFinter-individual variance of F, averaged across replicates
References
Weiser, E.L., Grueber, C. E., and I. G. Jamieson. In review. AlleleRetain: A program to assess management options for conserving allelic diversity in small, isolated populations. Molecular Ecology Resources.